@@ -17,7 +17,7 @@
 
 """setuptools plugin for projects maintained under Bazaar."""
 
-__version__ = '1.1'
+__version__ = '1.2'
 __all__ = [
     'find_files_for_bzr',
     ]
@@ -29,12 +29,19 @@ import subprocess
 try:
     from bzrlib.branch import Branch
     from bzrlib.errors import NotBranchError
+    from bzrlib.plugin import load_plugins
 except ImportError:
     Branch = None
 
 
+if os.getenv('BZR_SETUPTOOLS_FORCE_CMD'):
+    Branch = None
+
+
 def bzrlib_get_children(path):
     """Use direct bzrlib calls to get child information."""
+    # Be sure to register loom branch formats.
+    load_plugins()
     # Open an existing branch which contains the url.
     branch, inpath = Branch.open_containing(path)
     # Get the inventory of the branch's last revision.
